@@ -146,7 +146,12 @@ class Resource(FRSResource):
         """
         :return: JSON:API sort swagger spec (the collection sort key)
         """
-        attr_list = list(cls.SAFRSObject._s_jsonapi_attrs.keys()) + ["id"]
+        attr_list = ["id"]
+        for attr_name, col in cls.SAFRSObject._s_jsonapi_attrs.items():
+            # only use string or numbers for sortable examples in the swagger
+            # other column datatypes may not be sortable
+            if getattr(col, "type", None) in [sqlalchemy.String, sqlalchemy.Integer]:
+                attr_list.append(attr_name)
 
         param = {
             "default": ",".join(attr_list),
@@ -258,11 +263,12 @@ class SAFRSRestAPI(Resource):
             id = kwargs[self._s_object_id]
             instance = self.SAFRSObject.get_instance(id)
             data = instance
-            links = {"self": instance._s_url}
-            if request.url != instance._s_url:
-                links["related"] = request.url
             count = 1
-            meta.update(dict(instance_meta=instance._s_meta()))
+            if instance is not None:
+                links = {"self": instance._s_url}
+                if request.url != instance._s_url:
+                    links["related"] = request.url
+                meta.update(dict(instance_meta=instance._s_meta()))
         else:
             # retrieve a collection, filter and sort
             instances = self.SAFRSObject._s_get()
@@ -409,6 +415,8 @@ class SAFRSRestAPI(Resource):
 
         # Create a new instance of the SAFRSObject
         data = payload.get("data")
+        resp_data = {} # response jsonapi "data"
+        location = "" #response jsonapi "location"
         if data is None:
             raise ValidationError("Request contains no data")
         if isinstance(data, list):
@@ -425,11 +433,15 @@ class SAFRSRestAPI(Resource):
             location = None
         else:
             instance = self._create_instance(data)
-            # object_id is the endpoint parameter, for example "UserId" for a User SAFRSObject
-            obj_args = {instance._s_object_id: instance.jsonapi_id}
-            # Retrieve the object json and return it to the client
-            resp_data = self.get(**obj_args)
-            location = f"{url_for(self.endpoint)}{instance.jsonapi_id}"
+            object_id = getattr(instance, '_s_object_id', None)
+            if object_id is not None:
+                # object_id is the endpoint parameter, for example "UserId" for a User SAFRSObject
+                obj_args = {instance._s_object_id: instance.jsonapi_id}
+                # Retrieve the object json and return it to the client
+                resp_data = self.get(**obj_args)
+                location = f"{url_for(self.endpoint)}{instance.jsonapi_id}"
+            else:
+                safrs.log.warning(f"Created instance '{instance}' cannot be serialized")
 
         response = make_response(resp_data, HTTPStatus.CREATED)
         # Set the Location header to the newly created object(s)
@@ -575,7 +587,7 @@ class SAFRSRestRelationshipAPI(Resource):
     # Retrieve relationship data
     def get(self, **kwargs):
         """
-        summary : Retrieve {child_name} from {cls.relationship.key}
+        summary : Retrieve {child_name} from {parent_name}.{cls.relationship.key}
         description : Retrieve {child_name} items from the {parent_name} {cls.relationship.key} "{direction}" relationship
         ---
         https://jsonapi.org/format/#fetching-relationships
@@ -620,6 +632,7 @@ class SAFRSRestRelationshipAPI(Resource):
             instances = jsonapi_filter_list(relation)
             instances = jsonapi_sort(instances, self.target)
             links, data, count = paginate(instances, self.target)
+            count = len(data)
         else:
             # lazy='dynamic' relationships
             instances = jsonapi_filter_query(relation, self.target)
@@ -632,7 +645,7 @@ class SAFRSRestRelationshipAPI(Resource):
     # Relationship patching
     def patch(self, **kwargs):
         """
-        summary : Update {cls.relationship.key}
+        summary : Update {parent_name}.{cls.relationship.key}
         description : Update the {parent_name} {cls.relationship.key} "{direction}" relationship
         responses:
             200 :
@@ -746,7 +759,7 @@ class SAFRSRestRelationshipAPI(Resource):
     # Adding items to a relationship
     def post(self, **kwargs):
         """
-        summary: Add {child_name} items to {cls.relationship.key}
+        summary: Add {child_name} items to {parent_name}.{cls.relationship.key}
         description : Add {child_name} items to the {parent_name} {cls.relationship.key} "{direction}" relationship
         responses :
             202:
@@ -804,7 +817,7 @@ class SAFRSRestRelationshipAPI(Resource):
 
     def delete(self, **kwargs):
         """
-        summary : Delete {child_name} from {cls.relationship.key}
+        summary : Delete {child_name} from {parent_name}.{cls.relationship.key}
         description : Delete {child_name} items from the {parent_name} {cls.relationship.key} "{direction}" relationship
         responses:
             202 :
