@@ -85,8 +85,8 @@ class SAFRSRequest(Request):
     @property
     def page_limit(self):
         """
-       :return: page limit requested by the client when fetching lists
-       """
+        :return: page limit requested by the client when fetching lists
+        """
         page_limit = self.args.get("page[limit]", get_config("DEFAULT_PAGE_LIMIT"), type=int)
         if "page[number]" in self.args and "page[size]" in self.args:
             return self.args.get("page[size]", type=int)
@@ -104,7 +104,7 @@ class SAFRSRequest(Request):
         :return: jsonapi request payload
         """
         if not self.is_jsonapi:  # pragma: no cover
-            safrs.log.warning('Invalid Media Type! "{}"'.format(self.content_type))
+            safrs.log.warning(f'Invalid Media Type! "{self.content_type}"')
             # raise GenericError('Unsupported Media Type', 415)
         if self.method == "OPTIONS":
             return None
@@ -112,7 +112,7 @@ class SAFRSRequest(Request):
             abort(500)
         result = self.get_json()
         if not isinstance(result, dict):
-            raise ValidationError("Invalid JSON Payload : {}".format(result))
+            raise ValidationError(f"Invalid JSON Payload : {result}")
         return result
 
     def parse_jsonapi_args(self):
