@@ -2,7 +2,7 @@
 from http import HTTPStatus
 import logging
 import werkzeug
-from flask_restful import abort
+from flask_restful import abort, Resource
 from flask_restful.representations.json import output_json
 from flask_restful.utils import OrderedDict
 from flask_restful.utils import cors
@@ -20,8 +20,9 @@ from .config import get_config
 from .json_encoder import SAFRSJSONEncoder
 from ._safrs_relationship import SAFRSRelationshipObject
 from sqlalchemy.orm.interfaces import MANYTOONE
-from flask import current_app
+from flask import current_app, Response
 import json
+import yaml
 
 HTTP_METHODS = ["GET", "POST", "PATCH", "DELETE", "PUT"]
 DEFAULT_REPRESENTATIONS = [("application/vnd.api+json", output_json)]
@@ -36,6 +37,7 @@ class SAFRSAPI(FRSApiBase):
 
     _operation_ids = {}
     _custom_swagger = {}
+    _als_resources = []
 
     def __init__(
         self,
@@ -161,6 +163,14 @@ class SAFRSAPI(FRSApiBase):
             self._swagger_object["definitions"][def_name] = {"properties": definition.properties}
 
         self.update_spec()
+        self._als_resources.append(safrs_object)
+
+    def expose(self, *safrs_objects, url_prefix="", **properties):
+        """
+        Expose multiple objects at once
+        """
+        for obj in safrs_objects:
+            self.expose_object(obj, url_prefix, **properties)
 
     def expose_methods(self, url_prefix, tags, safrs_object, properties):
         """
@@ -518,6 +528,43 @@ class SAFRSAPI(FRSApiBase):
             cls._operation_ids[summary] += 1
         return f"{summary}_{cls._operation_ids[summary]}"
 
+    def expose_als_schema(self, api_root="/api", schema_loc="/als_schema"):
+        """
+        Generate the resource specification for apilogicserver
+        """
+        resources = {}
+        result = {"resources": resources, "api_root": api_root}
+        for resource in self._als_resources:
+            resource_data = {"type": resource._s_type, "label": None}
+            attributes = []
+            for name, attr_def in resource._s_jsonapi_attrs.items():
+                attr = {}
+                attr["name"] = name
+                # column["type"] = col.python_type
+                attributes.append(attr)
+            resource_data["attributes"] = attributes
+            resource_data["perPage"] = 10
+            relations = []
+            for rel_name, rel in resource._s_relationships.items():
+                relation = {}
+                relation["name"] = rel_name
+                relation["resource"] = str(rel.target.key)
+                relation["fks"] = [str(c.key) for c in rel._calculated_foreign_keys]
+                relation["direction"] = "toone" if rel.direction == MANYTOONE else "tomany"
+                relations.append(relation)
+            resource_data["tab_groups"] = relations
+
+            resources[resource._s_collection_name] = resource_data
+
+        class ApiSchema(Resource):
+            def get(self):
+                if request.args.get("yaml"):
+                    return Response(yaml.dump(result), content_type="text/yaml")
+                return result
+
+        self.add_resource(ApiSchema, schema_loc)
+        return json.dumps(result, indent=4)
+
 
 def api_decorator(cls, swagger_decorator):
     """Decorator for the API views:
@@ -606,6 +653,8 @@ def http_method_decorator(fun):
         :return: result of the wrapped method
         """
         safrs_exception = None
+        status_code = 500
+        message = ""
         try:
             if not request.is_jsonapi and fun.__name__ not in ["get", "head", "options", "delete"]:  # pragma: no cover
                 # reuire jsonapi content type for requests to these routes
@@ -614,13 +663,20 @@ def http_method_decorator(fun):
             safrs.DB.session.commit()
             return result
 
+        except werkzeug.exceptions.NotFound as exc:
+            # this also catches safrs.errors.NotFoundError
+            status_code = 404
+            safrs_exception = exc
+            message = HTTPStatus.NOT_FOUND.description
+
         except JsonapiError as exc:
             safrs.log.exception(exc)
             safrs_exception = exc
 
-        except werkzeug.exceptions.NotFound as exc:
-            status_code = 404
-            safrs_exception = exc
+        except werkzeug.exceptions.HTTPException as exc:
+            status_code = exc.code
+            message = exc.description
+            safrs.log.error(message)
 
         except Exception as exc:
             safrs.log.exception(exc)
@@ -630,13 +686,12 @@ def http_method_decorator(fun):
             else:
                 safrs_exception.message = str(exc)
 
-        status_code = getattr(safrs_exception, "status_code", 500)
+        status_code = getattr(safrs_exception, "status_code", status_code)
         api_code = getattr(safrs_exception, "api_code", status_code)
-        title = getattr(safrs_exception, "message", "")
+        title = getattr(safrs_exception, "message", message)
         detail = getattr(safrs_exception, "detail", title)
 
         safrs.DB.session.rollback()
-        safrs.log.error(detail)
         errors = dict(title=title, detail=detail, code=api_code)
         abort(status_code, errors=[errors])
 
